==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionButtonClickEventArgsDescription } from "./PropertyEditorPropertyDescriptionButtonClickEventArgsDescription";
/**
 * @hidden
 */
var PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata, _super);
    function PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.b = function (a) {
        if (PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a == null) {
            PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
        }
        if (a.g(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.c = function (a) {
    };
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.d = function (a) {
        PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.b(a);
        a.u("PropertyEditorPropertyDescriptionButtonClickEventArgs", function () { return new PropertyEditorPropertyDescriptionButtonClickEventArgsDescription(); });
        a.t("PropertyEditorPropertyDescriptionButtonClickEventArgs", PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.$t = markType(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata;
}(Base));
export { PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyEditorPropertyDescriptionButtonClickEventArgsDescription } from "./PropertyEditorPropertyDescriptionButtonClickEventArgsDescription";
/**
 * @hidden
 */
var PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata, _super);
    function PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.b = function (a) {
        if (PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a == null) {
            PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.c(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
        }
        if (a.j(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.c = function (a) {
    };
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.d = function (a) {
        PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.b(a);
        a.aa("PropertyEditorPropertyDescriptionButtonClickEventArgs", function () { return new PropertyEditorPropertyDescriptionButtonClickEventArgsDescription(); });
        a.z("PropertyEditorPropertyDescriptionButtonClickEventArgs", PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a);
    };
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.$t = markType(PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata, 'PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata');
    PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata.a = null;
    return PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata;
}(Base));
export { PropertyEditorPropertyDescriptionButtonClickEventArgsDescriptionMetadata };
